@@ -55,7 +55,7 @@
 #' 
 #' @importFrom doFuture registerDoFuture
 #' @importFrom doRNG %dorng%
-#' @importFrom foreach %do% %dopar% foreach
+#' @importFrom foreach %do% %dopar% foreach setDoPar
 #' @importFrom future multisession plan
 #' @importFrom iterators icount
 #' @importFrom raster crs
@@ -142,8 +142,9 @@ perlrren <- function(obs_ppp,
   
   ### Set function used in foreach
   if (parallel == TRUE) {
-    doFuture::registerDoFuture()
-    future::plan(multisession, workers = n_core)
+    oldplan <- doFuture::registerDoFuture()
+    on.exit(with(oldplan, foreach::setDoPar(fun=fun, data=data, info=info)), add = TRUE)
+    future::plan(future::multisession, workers = n_core)
     `%fun%` <- doRNG::`%dorng%`
   } else { `%fun%` <- foreach::`%do%` }
   
